@@ -280,17 +280,29 @@ def addBikeshedBoilerplate(doc):
 
 
 def addIndexSection(doc):
-    if len(h.findAll(config.dfnElementsSelector, doc)) == 0 and len(list(doc.externalRefsUsed.keys())) == 0:
+    hasLocalDfns = len(h.findAll(config.dfnElementsSelector, doc)) > 0
+    hasExternalDfns = False
+    for spec, refs in doc.externalRefsUsed.items():
+        # refs is a {ref text => ref} table
+        # but it can also have a _biblio key
+        # to track biblio references.
+        # Need to make sure it doesn't contain *only* _biblio
+        if "_biblio" in refs and len(refs) == 1:
+            continue
+        hasExternalDfns = True
+        break
+    if not hasLocalDfns and not hasExternalDfns:
         return
+
     container = getFillContainer("index", doc=doc, default=True)
     if container is None:
         return
     h.appendChild(container, h.E.h2({"class": "no-num no-ref", "id": h.safeID(doc, "index")}, "Index"))
 
-    if len(h.findAll(config.dfnElementsSelector, doc)) > 0:
+    if hasLocalDfns:
         addIndexOfLocallyDefinedTerms(doc, container)
 
-    if len(list(doc.externalRefsUsed.keys())) > 0:
+    if hasExternalDfns:
         addIndexOfExternallyDefinedTerms(doc, container)
 
 
@@ -539,6 +551,11 @@ def addIndexOfExternallyDefinedTerms(doc, container):
             printableSpec = biblioRef.linkText
         else:
             printableSpec = spec
+
+        # Skip entries that are *solely* a biblio entry.
+        if "_biblio" in refGroups and len(refGroups) == 1:
+            continue
+
         attrs = {
             "data-lt": spec,
             "data-link-type": "biblio",
@@ -1130,6 +1147,7 @@ def addReferencesSection(doc):
     )
 
     normRefs = sorted(doc.normativeRefs.values(), key=lambda r: r.linkText.lower())
+    normRefKeys = set(r.linkText.lower() for r in doc.normativeRefs.values())
     if len(normRefs) > 0:
         dl = h.appendChild(
             container,
@@ -1153,7 +1171,7 @@ def addReferencesSection(doc):
     informRefs = [
         x
         for x in sorted(doc.informativeRefs.values(), key=lambda r: r.linkText.lower())
-        if x.linkText not in doc.normativeRefs
+        if x.linkText.lower() not in normRefKeys
     ]
     if len(informRefs) > 0:
         dl = h.appendChild(
