@@ -26,16 +26,18 @@ from lxml import etree
 from typing_extensions import Literal, TypeAlias
 
 
-ElementT: TypeAlias = etree._Element  # pylint: disable=protected-access
-DocumentT: TypeAlias = etree._ElementTree  # pylint: disable=protected-access
-NodeT: TypeAlias = Union[str, ElementT]
+ElementT = etree._Element  # pylint: disable=protected-access
+DocumentT = etree._ElementTree  # pylint: disable=protected-access
+NodeT = Union[str, ElementT]
 
 # Can't actually do recursive types yet :(
 # Get as close as possible, but let lists be Any
-NodesT: TypeAlias = Union[NodeT, List]
+NodesT = Union[NodeT, List]
 
 
 if TYPE_CHECKING:
     if "Spec" not in sys.modules:
         from .Spec import Spec  # pylint: disable=cyclic-import
-    SpecType: TypeAlias = Union["Spec"]
+    SpecT = Spec
+else:
+    SpecT = None
